import fs from "fs";
import nodemailer from 'nodemailer';
import { MailOptions } from 'nodemailer/lib/json-transport';
import Mail from 'nodemailer/lib/mailer';
import { config } from './config';
import { MailServerConfigError } from './errors/MailErrors';
/**
 * This class is responsible for all things mail sending.
 */
export class Mailer {
    private transport: Mail;

    constructor() {
        this.transport = nodemailer.createTransport({
            host: config.mail_server,
            port: config.mail_port,
            auth: {
                user: config.mail_user,
                pass: config.mail_password
            }
        });

        this.transport.verify(function (error, success) {
            if (error) {
                throw new MailServerConfigError();
            }
        });
    }

    public async sendResetMail(to_address: string, token: String) {
        const reset_link = `${config.app_url}/reset/${token}`
        const body_html = fs.readFileSync(__dirname + '/static/mail_templates/pw-reset.html', { encoding: 'utf8' }).replace("{{reset_link}}", reset_link).replace("{{recipient_mail}}", to_address).replace("{{copyright_owner}}", "LfK!").replace("{{link_imprint}}", `${config.app_url}/imprint`).replace("{{link_privacy}}", `${config.app_url}/privacy`);
        const body_txt = fs.readFileSync(__dirname + '/static/mail_templates/pw-reset.html', { encoding: 'utf8' }).replace("{{reset_link}}", reset_link).replace("{{recipient_mail}}", to_address).replace("{{copyright_owner}}", "LfK!").replace("{{link_imprint}}", `${config.app_url}/imprint`).replace("{{link_privacy}}", `${config.app_url}/privacy`);

        const mail: MailOptions = {
            to: to_address,
            subject: "LfK! Password Reset",
            text: body_txt,
            html: body_html
        };
        await this.sendMail(mail);
    }

    public async sendMail(mail: MailOptions) {
        mail.from = config.mail_from;
        await this.transport.sendMail(mail);
    }
}
